require File.expand_path('../../spec_helper', __FILE__)

describe RbPass::PasswordHasher do
  context 'when using system-specific hashes' do
    let(:password_hasher)     { RbPass::PasswordHasher.new(8, false) }
    let(:valid_password)      { 'test12345' }
    let(:invalid_password)    { 'test12346' }
    let(:valid_password_hash) { password_hasher.hash(valid_password) }

    it 'returns true if a valid password is passed' do
      password_hasher.check(valid_password, valid_password_hash).should be_true
    end

    it 'returns false if an invalid password is passed' do
      password_hasher.check(invalid_password, valid_password_hash).should be_false
    end
  end

  context 'when using portable hashes' do
    let(:password_hasher)     { RbPass::PasswordHasher.new(8, true) }
    let(:valid_password)      { 'test12345' }
    let(:invalid_password)    { 'test12346' }
    let(:valid_password_hash) { password_hasher.hash(valid_password) }

    it 'returns true if a valid password is passed' do
      password_hasher.check(valid_password, valid_password_hash).should be_true
    end

    it 'returns false if an invalid password is passed' do
      password_hasher.check(invalid_password, valid_password_hash).should be_false
    end
  end

  context 'when using portable hashes and a random hardcoded hash' do
    let(:password_hasher)     { RbPass::PasswordHasher.new(8, true) }
    let(:valid_password)      { 'test12345' }
    let(:invalid_password)    { 'test12346' }
    let(:valid_password_hash) { '$P$9IQRaTwmfeRo7ud9Fh4E2PdI0S3r.L0' } # A correct portable hash for 'test12345'

    it 'returns true if a valid password is passed' do
      password_hasher.check(valid_password, valid_password_hash).should be_true
    end

    it 'returns false if an invalid password is passed' do
      password_hasher.check(invalid_password, valid_password_hash).should be_false
    end
  end
end